@@ -54,7 +54,7 @@ add_text <- function(plot,
 
   # Row must be provided for the body
   if(part == "body" & is.null(row))
-    stop("Row must be defined if the text is interting to body.")
+    stop("Row must be defined if the text is inserting to body.")
 
   # Align text
   tx_x <- switch(just,
