@@ -12,6 +12,8 @@
 #' @param vgap Vertical gap between the legend entries,
 #' see \code{\link[grid]{legendGrob}} for details.
 #' @param gp Graphical parameters.
+#' @param ncol integer; the number of columns
+#' @param byrow logical indicating whether rows of the legend are filled first.
 #' @param ... Other parameters, not used currently.
 #'
 #' @return A frame grob
@@ -23,11 +25,13 @@ legend_grob <- function(name = "",
                         hgap = unit(0.1, "lines"), #horizontal gap
                         vgap = unit(0.5, "lines"), #vertical gap
                         pch = 15,
+                        ncol = 1,
                         gp = gpar(lty = 1,
                                   col = "black",
                                   fill = "black",
                                   fontsize = 12,
                                   fontfamily = ""),
+                        byrow = TRUE,
                         ...
 ){
 
@@ -44,18 +48,12 @@ legend_grob <- function(name = "",
                                    fontface = 'bold',
                                    fill = 'black'))
 
-  if(position %in% c("top", "bottom")){
-    by_row <- FALSE
+  if(position %in% c("top", "bottom") & ncol == 1)
     ncol <- length(gp$col)
 
-  }else{
-    by_row <- TRUE
-    ncol <- 1
-  }
-
   # LegendGrob
   leg_grob <- legendGrob(label, pch = pch, ncol = ncol,
-                         do.lines = TRUE, byrow = by_row,
+                         do.lines = TRUE, byrow = byrow,
                          hgap = hgap*gp$cex, vgap = vgap*gp$cex,
                          gp = gp)
 
